@@ -579,7 +579,7 @@ socket_ref_state_set (AtkObject *accessible)
 }
 
 static void
-socket_embed_hook (AtkSocket * socket, gchar * plug_id)
+socket_embed_hook (AtkSocket * socket, const gchar * plug_id)
 {
   g_return_if_fail (spi_global_register != NULL);
 
